@@ -20,7 +20,7 @@ typedef Eo Ecore_Audio_Out_Pulse;
  */
 #define ECORE_AUDIO_OUT_PULSE_CLASS ecore_audio_out_pulse_class_get()
 
-EWAPI const Efl_Class *ecore_audio_out_pulse_class_get(void);
+EWAPI const Efl_Class *ecore_audio_out_pulse_class_get(void) EINA_CONST;
 
 EWAPI extern const Efl_Event_Description _ECORE_AUDIO_OUT_PULSE_EVENT_CONTEXT_READY;
 
