@@ -88,7 +88,7 @@ typedef struct _Efl_Access_Text_Change_Info
  */
 #define EFL_ACCESS_TEXT_INTERFACE efl_access_text_interface_get()
 
-EWAPI const Efl_Class *efl_access_text_interface_get(void);
+EWAPI const Efl_Class *efl_access_text_interface_get(void) EINA_CONST;
 
 #ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_TEXT_PROTECTED
@@ -117,16 +117,16 @@ EOAPI Eina_Unicode efl_access_text_character_get(const Eo *obj, int offset);
  *
  * @param[in] obj The object.
  * @param[in] granularity Text granularity
- * @param[in] start_offset Offset indicating start of string according to given
+ * @param[out] start_offset Offset indicating start of string according to
+ * given granularity. -1 in case of error.
+ * @param[out] end_offset Offset indicating end of string according to given
  * granularity. -1 in case of error.
- * @param[in] end_offset Offset indicating end of string according to given
- * granularity. -1 in case of error.
- *
- * @return Newly allocated UTF-8 encoded string. Must be free by a user.
+ * @param[out] string Newly allocated UTF-8 encoded string. Must be free by a
+ * user.
  *
  * @ingroup Efl_Access_Text
  */
-EOAPI char *efl_access_text_string_get(const Eo *obj, Efl_Access_Text_Granularity granularity, int *start_offset, int *end_offset) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+EOAPI void efl_access_text_string_get(const Eo *obj, Efl_Access_Text_Granularity granularity, int *start_offset, int *end_offset, char **string EFL_TRANSFER_OWNERSHIP);
 #endif
 #endif /* EFL_BETA_API_SUPPORT */
 
@@ -185,8 +185,8 @@ EOAPI int efl_access_text_caret_offset_get(const Eo *obj);
  *
  * @param[in] obj The object.
  * @param[in] name Text attribute name
- * @param[in] start_offset Position in text from which given attribute is set.
- * @param[in] end_offset Position in text to which given attribute is set.
+ * @param[out] start_offset Position in text from which given attribute is set.
+ * @param[out] end_offset Position in text to which given attribute is set.
  * @param[out] value Value of text attribute. Should be free()
  *
  * @return @c true if attribute name is set, @c false otherwise
@@ -203,14 +203,13 @@ EOAPI Eina_Bool efl_access_text_attribute_get(const Eo *obj, const char *name, i
  * @brief Gets list of all text attributes.
  *
  * @param[in] obj The object.
- * @param[in] start_offset Start offset
- * @param[in] end_offset End offset
- *
- * @return List of text attributes
+ * @param[out] start_offset Start offset
+ * @param[out] end_offset End offset
+ * @param[out] attributes List of text attributes
  *
  * @ingroup Efl_Access_Text
  */
-EOAPI Eina_List *efl_access_text_attributes_get(const Eo *obj, int *start_offset, int *end_offset) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+EOAPI void efl_access_text_attributes_get(const Eo *obj, int *start_offset, int *end_offset, Eina_List **attributes EFL_TRANSFER_OWNERSHIP);
 #endif
 #endif /* EFL_BETA_API_SUPPORT */
 
