@@ -21,6 +21,6 @@ typedef Eo Efl_Ui_Alert_Popup_Part_Title;
  */
 #define EFL_UI_ALERT_POPUP_PART_TITLE_CLASS efl_ui_alert_popup_part_title_class_get()
 
-EWAPI const Efl_Class *efl_ui_alert_popup_part_title_class_get(void);
+EWAPI const Efl_Class *efl_ui_alert_popup_part_title_class_get(void) EINA_CONST;
 
 #endif
