@@ -94,7 +94,7 @@ typedef enum
  */
 #define EFL_UI_FORMAT_MIXIN efl_ui_format_mixin_get()
 
-EWAPI const Efl_Class *efl_ui_format_mixin_get(void);
+EWAPI const Efl_Class *efl_ui_format_mixin_get(void) EINA_CONST;
 
 /**
  * @brief User-provided function which takes care of converting an
