@@ -20,7 +20,7 @@ typedef Eo Efl_Ui_Scroll_Manager;
  */
 #define EFL_UI_SCROLL_MANAGER_CLASS efl_ui_scroll_manager_class_get()
 
-EWAPI const Efl_Class *efl_ui_scroll_manager_class_get(void);
+EWAPI const Efl_Class *efl_ui_scroll_manager_class_get(void) EINA_CONST;
 
 #ifdef EFL_UI_SCROLL_MANAGER_PROTECTED
 /**
@@ -31,7 +31,7 @@ EWAPI const Efl_Class *efl_ui_scroll_manager_class_get(void);
  * set to @c NULL, scrolling does not work.
  *
  * @param[in] obj The object.
- * @param[in] pan Pan object
+ * @param[in] pan Pan object.
  *
  * @ingroup Efl_Ui_Scroll_Manager
  */
