@@ -20,7 +20,7 @@ typedef Eo Efl_Ui_Textbox_Part;
  */
 #define EFL_UI_TEXTBOX_PART_CLASS efl_ui_textbox_part_class_get()
 
-EWAPI const Efl_Class *efl_ui_textbox_part_class_get(void);
+EWAPI const Efl_Class *efl_ui_textbox_part_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
