@@ -20,7 +20,7 @@ typedef Eo Elm_Actionslider_Part;
  */
 #define ELM_ACTIONSLIDER_PART_CLASS elm_actionslider_part_class_get()
 
-EWAPI const Efl_Class *elm_actionslider_part_class_get(void);
+EWAPI const Efl_Class *elm_actionslider_part_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
