@@ -20,7 +20,7 @@ typedef Eo Elm_Panel_Part;
  */
 #define ELM_PANEL_PART_CLASS elm_panel_part_class_get()
 
-EWAPI const Efl_Class *elm_panel_part_class_get(void);
+EWAPI const Efl_Class *elm_panel_part_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
