@@ -25,7 +25,7 @@ typedef Eo Efl_Canvas_Proxy;
  */
 #define EFL_CANVAS_PROXY_CLASS efl_canvas_proxy_class_get()
 
-EWAPI const Efl_Class *efl_canvas_proxy_class_get(void);
+EWAPI const Efl_Class *efl_canvas_proxy_class_get(void) EINA_CONST;
 
 /**
  * @brief The source object for this proxy.
