@@ -31,7 +31,7 @@ typedef Eo Efl_Canvas_Gesture;
  */
 #define EFL_CANVAS_GESTURE_CLASS efl_canvas_gesture_class_get()
 
-EWAPI const Efl_Class *efl_canvas_gesture_class_get(void);
+EWAPI const Efl_Class *efl_canvas_gesture_class_get(void) EINA_CONST;
 
 /**
  * @brief Current state of the gesture, from initial detection to successful
