@@ -21,7 +21,7 @@ typedef Eo Efl_Canvas_Gesture_Recognizer_Zoom;
  */
 #define EFL_CANVAS_GESTURE_RECOGNIZER_ZOOM_CLASS efl_canvas_gesture_recognizer_zoom_class_get()
 
-EWAPI const Efl_Class *efl_canvas_gesture_recognizer_zoom_class_get(void);
+EWAPI const Efl_Class *efl_canvas_gesture_recognizer_zoom_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
